# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.17.0] - 2025-06-22

### Added

- Support for `ffmpeg-normalize` for normalization (optional)

### Changed

- Configuration options for normalization selection
- Configuration options for `ffmpeg-normalize`
